==> clutternomore-1.1.2%2B1.21.5-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/creative/CreativeModeTabEntriesMixin.java <==
package dev.tazer.clutternomore.common.mixin.creative;

import dev.tazer.clutternomore.common.CHooks;
import dev.tazer.clutternomore.common.shape_map.ShapeMap;
//? neoforge {
/*import net.neoforged.neoforge.event.BuildCreativeModeTabContentsEvent;
 *///?} else if fabric {
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroupEntries;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

//? if neoforge || forge {
/*@Mixin(BuildCreativeModeTabContentsEvent.class)
 *///?} else {
@Mixin(FabricItemGroupEntries.class)
//?}
public abstract class CreativeModeTabEntriesMixin {
    //? if forge {
    /*@Inject(method = "accept", at = @At("HEAD"), cancellable = true)
    private void accept(ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
    }
    *///?} else if neoforge {
    /*@Shadow
    public abstract void insertBefore(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility);

    @Shadow
    public abstract void insertAfter(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility);

    @Inject(method = "accept", at = @At("HEAD"), cancellable = true)
    private void accept(ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
    }

    @Inject(method = "insertAfter", at = @At("HEAD"), cancellable = true)
    private void insertAfter(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
        if (ShapeMap.isShape(existingEntry.getItem())) {
            insertAfter(ShapeMap.getParent(existingEntry.getItem()).getDefaultInstance(), newEntry, visibility);
            ci.cancel();
        }
    }

    @Inject(method = "insertBefore", at = @At("HEAD"), cancellable = true)
    private void insertBefore(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
        if (ShapeMap.isShape(existingEntry.getItem())) {
            insertBefore(ShapeMap.getParent(existingEntry.getItem()).getDefaultInstance(), newEntry, visibility);
            ci.cancel();
        }
    }
    *///?} else {

    @Inject(method = "accept", at = @At("HEAD"), cancellable = true)
    private void accept(class_1799 newEntry, class_1761.class_7705 visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.method_7909())) ci.cancel();
    }

    @Inject(method = "isEnabled", at = @At("RETURN"), cancellable = true)
    private void accept(class_1799 stack, CallbackInfoReturnable<Boolean> cir) {
        if (CHooks.denyItem(stack.method_7909())) cir.setReturnValue(false);
    }
    //?}
}

==> clutternomore-1.1.4%2B1.21.8-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/creative/CreativeModeTabEntriesMixin.java <==
package dev.tazer.clutternomore.common.mixin.creative;

import dev.tazer.clutternomore.common.CHooks;
import dev.tazer.clutternomore.common.shape_map.ShapeMap;
//? neoforge {
/*import net.neoforged.neoforge.common.util.InsertableLinkedOpenCustomHashSet;
import net.neoforged.neoforge.event.BuildCreativeModeTabContentsEvent;
 *///?} else if fabric {
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroupEntries;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

//? if neoforge || forge {
/*@Mixin(BuildCreativeModeTabContentsEvent.class)
 *///?} else {
@Mixin(FabricItemGroupEntries.class)
//?}
public abstract class CreativeModeTabEntriesMixin {
    //? if forge {
    /*@Inject(method = "accept", at = @At("HEAD"), cancellable = true)
    private void accept(ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
    }
    *///?} else if neoforge {
    /*@Shadow
    public abstract void insertBefore(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility);

    @Shadow
    public abstract void insertAfter(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility);

    @Inject(method = "accept", at = @At("HEAD"), cancellable = true)
    private void accept(ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
    }

    @Inject(method = "insertAfter", at = @At("HEAD"), cancellable = true)
    private void insertAfter(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
        if (ShapeMap.isShape(existingEntry.getItem())) {
            insertAfter(ShapeMap.getParent(existingEntry.getItem()).getDefaultInstance(), newEntry, visibility);
            ci.cancel();
        }
    }

    @Inject(method = "insertBefore", at = @At("HEAD"), cancellable = true)
    private void insertBefore(ItemStack existingEntry, ItemStack newEntry, CreativeModeTab.TabVisibility visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.getItem())) ci.cancel();
        if (ShapeMap.isShape(existingEntry.getItem())) {
            insertBefore(ShapeMap.getParent(existingEntry.getItem()).getDefaultInstance(), newEntry, visibility);
            ci.cancel();
        }
    }
    @Inject(method = "assertTargetExists", at = @At("HEAD"), cancellable = true)
    private void insertBefore(InsertableLinkedOpenCustomHashSet<ItemStack> setToCheck, ItemStack existingEntry, CallbackInfo ci) {
        ci.cancel();
    }
    *///?} else {

    @Inject(method = "accept", at = @At("HEAD"), cancellable = true)
    private void accept(class_1799 newEntry, class_1761.class_7705 visibility, CallbackInfo ci) {
        if (CHooks.denyItem(newEntry.method_7909())) ci.cancel();
    }

    @Inject(method = "isEnabled", at = @At("RETURN"), cancellable = true)
    private void accept(class_1799 stack, CallbackInfoReturnable<Boolean> cir) {
        if (CHooks.denyItem(stack.method_7909())) cir.setReturnValue(false);
    }
    //?}
}
